%define _disable_ld_no_undefined 1

%global __requires_exclude_from %{_docdir}


# The version flow of zsh: N - N-dev-1 - ... - (N+1)-prel-1 ... (N+1)
#define dev  0
#define prel 0
%define zshversion 5.8

# rel to bump
%define rel 3

%if %{?dev:1}%{!?dev:0} && %{?prel:1}%{!?prel:0}
%{error:Both %%prel and %%dev defined}
%endif

%if %{?dev:1}%{!?dev:0} || %{?prel:1}%{!?prel:0}
%define devdir development/
%endif

%define srcversion %{zshversion}%{?prel:-prel-%{prel}}%{?dev:-dev-%{dev}}

Summary:	A shell with lots of features
Name:		zsh
Epoch: 		1
Version:	%zshversion%{?dev:.dev%{dev}}
Release:	%mkrel %{?prel:0.prel%{prel}.}%{rel}
Url:		http://www.zsh.org
License:	MIT
Group:		Shells
Source0:	https://sourceforge.net/projects/zsh/files/zsh/%{version}/%{?devdir}%{name}-%{srcversion}.tar.xz
Source1:	https://sourceforge.net/projects/zsh/files/zsh-doc/%{version}/%{?devdir}%{name}-%{srcversion}-doc.tar.xz
Source2:	zcfg-mga.tar.bz2
Source3:	http://zsh.sourceforge.net/Guide/zshguide_html.tar.gz#/zshguide_html-%{srcversion}.tar.gz
Source4:	zsh.urpmi_comp
#Patch1:		zsh-gawk-warning.patch
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	libtermcap-devel >= 2.0
BuildRequires:	texinfo
BuildRequires:	pkgconfig(libpcre)
BuildRequires:	rpm-helper >= 0.18.5
BuildRequires:	gdbm-devel
BuildRequires:	groff

Requires(postun): rpm-helper
Requires(post): rpm-helper

%description
Zsh is a UNIX command interpreter (shell) usable as an
interactive login shell and as a shell script command
processor. Of the standard shells, zsh most closely resembles
ksh but includes many enhancements. Zsh has command-line editing,
built-in spelling correction, programmable command completion,
shell functions (with autoloading), a history mechanism, and a
lots of other features

Install the zsh package if you'd like to try out a different shell.

%package doc
Summary:	The doc package of zsh
Group:		Documentation
BuildArch:	noarch

%description doc
Zsh is a UNIX command interpreter (shell) usable as an
interactive login shell and as a shell script command
processor. Of the standard shells, zsh most closely resembles
ksh but includes many enhancements. Zsh has command-line editing,
built-in spelling correction, programmable command completion,
shell functions (with autoloading), a history mechanism, and a
lots of other features

This package include doc guid examples and manual for zsh.

%prep
%setup -q -a 2 -a 1 -n %{name}-%{srcversion}
%autopatch -p1

# Delete one test that fails using iurt
rm -f Test/C02cond.ztst

mv %{name}-%{srcversion}/Doc/* Doc/

mv -f Completion/Mandriva Completion/%{_vendor}
%__perl -i -lp -e 's@Completion/Mandriva/@Completion/%{_vendor}/@g' Src/Zle/complete.mdd

install -m 0644 %{SOURCE4}  Completion/%{_vendor}/Command/_urpmi

# remove temporary files
find | grep '~$' | xargs rm -f
perl -pi -e 's|/usr/local/bin/|%{_bindir}/|' Functions/Misc/{run-help,checkmail,zcalc}

%build
# check for tcsetpgrp fails with "configure: error: no controlling tty" when
# building by bot; force tcsetpgrp
%configure \
	--enable-etcdir=%{_sysconfdir} \
	--enable-function-subdirs \
%ifarch sparc
	--disable-lfs \
%endif
	--enable-pcre \
	--with-tcsetpgrp
%make_build all

%install
%make_install install.info

# copy Mageia Configuration files.
mkdir -p %{buildroot}/{bin,etc}
cp -a zcfg/etc/z* %{buildroot}%{_sysconfdir}
cp -a zcfg/share/zshrc_default %{buildroot}%{_datadir}/%{name}/%{srcversion}/zshrc_default

# this prevents RPM helper from adding dependency on /usr/bin/zsh
find %{buildroot}%{_datadir}/%{name}/%{srcversion} -type f -exec chmod 0644 '{}' \;

# Backward compatibilie should be removed in the others times.
pushd %{buildroot}/bin && {
    mv ..%{_bindir}/%{name} ./%{name}
} && popd

# zshall.1 includes all other man pages which does not work with compressed
# files. Generate full contents here
pushd %{buildroot}%{_mandir} && {
    /usr/bin/soelim man1/zshall.1 > zshall-full
    mv zshall-full man1/zshall.1
    popd
}

rm -f %{buildroot}%{_bindir}/%{name}-%{srcversion}

# Copy documentation.
rm -rf docroot
mkdir -p docroot/{Info_html,Examples,Documentation}/

cp -a README docroot/
cp -a Functions/Misc/* Misc/* Util/* docroot/Examples/
cp -a INSTALL ChangeLog* docroot/Documentation
cp -a StartupFiles docroot/
cp -a Etc/* docroot/Documentation
cp -a Doc/*html docroot/Info_html/

mkdir -p docroot/Zsh_Guide
tar xzf %SOURCE3 -C docroot/Zsh_Guide
mv docroot/Zsh_Guide/zshguide/*html docroot/Zsh_Guide/
rm -Rf docroot/Zsh_Guide/zshguide/

# Doc
rm -f docroot/{StartupFiles/.distfiles,Examples/{Makefile*,*.yo},Documentation/{Makefile*,*.yo}}
find docroot/ -name 'Makefile*' -o -name '.yo'|xargs rm -f
find docroot/ -type f|xargs perl -pi -e 's@^#!%{_prefix}/local/bin/(perl|zsh)@#!%{_bindir}/\1@'
mv docroot/Examples/compctl-examples docroot/StartupFiles

%check
%__make test

%post
%_post_shelladd /bin/zsh

%postun
%{_rpm_helper_dir}/del-shell %{name} $1 /bin/zsh

%files
%doc docroot/README NEWS
%doc %{_datadir}/%{name}/%{srcversion}/help
%config(noreplace) %{_sysconfdir}/z*
/bin/%{name}
%{_mandir}/man1/*.1*
%{_infodir}/*.info*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{srcversion}/
%{_datadir}/%{name}/%{srcversion}/functions
%{_datadir}/%{name}/%{srcversion}/scripts
%{_datadir}/%{name}/%{srcversion}/zshrc_default
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/%{srcversion}/
%{_datadir}/%{name}/site-functions/

%files doc
%doc docroot/Documentation/ docroot/Examples/ docroot/Info_html/
%doc docroot/StartupFiles/ docroot/Zsh_Guide ChangeLog* LICENCE


%changelog
* Fri Oct 23 2020 akien <akien> 1:5.8-3.mga8
+ Revision: 1638855
- Rebuild against fixed ncurses (6.2-20200831 caused FTBFS)

* Thu Aug 20 2020 ovitters <ovitters> 1:5.8-2.mga8
+ Revision: 1616563
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Thu Feb 27 2020 daviddavid <daviddavid> 1:5.8-1.mga8
+ Revision: 1550916
- new version: 5.8, fixes CVE-2019-20044 (mga#26252)

* Fri Feb 14 2020 umeabot <umeabot> 1:5.7.1-2.mga8
+ Revision: 1522626
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Feb 04 2019 kekepower <kekepower> 1:5.7.1-1.mga7
+ Revision: 1363030
- Update to version 5.7.1

* Fri Jan 25 2019 kekepower <kekepower> 1:5.7-1.mga7
+ Revision: 1360649
- Update to version 5.7
- Update sources
- Remove merged patch

* Fri Dec 07 2018 shlomif <shlomif> 1:5.6.2-3.mga7
+ Revision: 1338850
- Fix the Mandriva->Mageia completions move.

* Thu Nov 01 2018 shlomif <shlomif> 1:5.6.2-2.mga7
+ Revision: 1327524
- fix ack completion

* Sun Sep 16 2018 daviddavid <daviddavid> 1:5.6.2-1.mga7
+ Revision: 1259268
- new version: 5.6.2

* Tue Sep 11 2018 kekepower <kekepower> 1:5.6.1-1.mga7
+ Revision: 1258450
- Update to version 5.6.1

* Fri Jul 13 2018 wally <wally> 1:5.5.1-3.mga7
+ Revision: 1243364
- fix build on aarch64

* Tue Jun 26 2018 kekepower <kekepower> 1:5.5.1-2.mga7
+ Revision: 1239931
- Update Source3 link to use zsh version in filename
- Why build the docs when there is a readily available tarball
- Remove BR for yodl
- Rebuild for new gdbm
+ luigiwalser <luigiwalser>
- rebuild for gdbm

* Thu Apr 19 2018 kekepower <kekepower> 1:5.5.1-1.mga7
+ Revision: 1220123
- Update to version 5.5.1
- Enable tests

* Sun Apr 08 2018 kekepower <kekepower> 1:5.5-1.mga7
+ Revision: 1216291
- Update to version 5.5
- Removed CVE patches merged upstream
- Fixed Source0 link to use .xz

* Mon Mar 12 2018 kekepower <kekepower> 1:5.4.2-2.mga7
+ Revision: 1208256
- Added 2 patches from Ubuntu to fix CVE-2018-7548 and CVE-2018-7549 (mga#22741)

* Sun Nov 12 2017 shlomif <shlomif> 1:5.4.2-1.mga7
+ Revision: 1177070
- New version 5.4.2 (thanks to kekePower)

* Sun May 28 2017 shlomif <shlomif> 1:5.3.1-1.mga6
+ Revision: 1105285
- New version 5.3.1 (mga#20941)

* Sun Aug 21 2016 wally <wally> 1:5.2-6.mga6
+ Revision: 1047595
- fix zsh removal from /etc/shells after uninstall

* Thu Dec 17 2015 shlomif <shlomif> 1:5.2-5.mga6
+ Revision: 911450
- New version 5.2

* Wed Oct 15 2014 umeabot <umeabot> 1:5.0.5-5.mga5
+ Revision: 748359
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:5.0.5-4.mga5
+ Revision: 726062
- fix doc package requires

* Fri Sep 26 2014 tv <tv> 1:5.0.5-3.mga5
+ Revision: 725131
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1:5.0.5-2.mga5
+ Revision: 690891
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 pterjan <pterjan> 1:5.0.5-1.mga5
+ Revision: 661586
- Update to 5.0.5

* Sat Oct 19 2013 umeabot <umeabot> 1:5.0.2-3.mga4
+ Revision: 533096
- Mageia 4 Mass Rebuild

* Sun Aug 25 2013 luigiwalser <luigiwalser> 1:5.0.2-2.mga4
+ Revision: 471653
- add patch from omdv to fix build with texinfo 5.1

* Thu Jul 04 2013 dams <dams> 1:5.0.2-1.mga4
+ Revision: 450172
- new version 5.0.2

* Mon Jan 14 2013 umeabot <umeabot> 1:5.0.0-5.mga3
+ Revision: 387776
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 fwang <fwang> 1:5.0.0-4.mga3
+ Revision: 323870
- rebuild for new pcre

* Wed Oct 17 2012 malo <malo> 1:5.0.0-3.mga3
+ Revision: 307661
- make the doc package noarch

* Wed Oct 17 2012 malo <malo> 1:5.0.0-2.mga3
+ Revision: 307656
- update RPM group

* Fri Aug 10 2012 shlomif <shlomif> 1:5.0.0-1.mga3
+ Revision: 280457
- New version 5.0.0

* Wed Jun 06 2012 shlomif <shlomif> 1:4.3.17-1.mga3
+ Revision: 256646
- Update the license field to the Fedora choice
- Convert tabs to spaces (rpmlint)
- New version: 4.3.17

* Sat Mar 05 2011 dmorgan <dmorgan> 1:4.3.11-1.mga2
+ Revision: 64956
- Fix build
- Adapt for mageia
+ ennael <ennael>
- imported package zsh

